/*--------------------------------*- C++ -*----------------------------------*\
| =========                 |                                                 |
| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\    /   O peration     | Version:  2.3.1                                 |
|   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
|    \\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/
FoamFile
{
    version     2.0;
    `format'      ascii;
    class       dictionary;
    object      blockMeshDict;
}
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// General m4 macros

changecom(//)changequote([,]) dnl>
define(calc, [esyscmd(perl -e 'use Math::Trig; print ($1)')]) dnl>
define(VCOUNT, 0)
define(vlabel, [[// ]Vertex $1 = VCOUNT define($1, VCOUNT)define([VCOUNT], incr(VCOUNT))])

define(hex2D, hex (b$1 b$2 b$3 b$4 f$1 f$2 f$3 f$4))
define(quad2D, (b$1 b$2 f$2 f$1))
define(frontQuad, (f$1 f$2 f$3 f$4))
define(backQuad, (b$1 b$4 b$3 b$2))

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// User-defined parameters

convertToMeters 1e-3; //because engineers prefer it in mm
define(thickness, 1.0) // thickness of shot sleeve slice (x-direction)
define(sSDiameter, 60) // height of shot sleeve slice (y-direction)/diameter of shot sleeve
define(lengthOfMovSleeve, 280) // length of moving area in shot sleeve (z-direction)

define(lengthOfFixSleeve, 20) //lenght of fixed area in shot sleeve (z-direction)
define(outletHeight, 20) //height of the outlet "chimney" (y-direction)
define(Nt, 1) // Number of cells in the length (1 for 2D) (x-direction)
define(NmA, 37) // Number of cells in the moving area (z-direction)
define(NHoSS, 15) // Number of cells in the height of the shot sleeve (y-direction)
define(NfA, 5) // Number of cells in the fixed area (z-direction)
define(NOH, 10) // Number of cells in the height of the outlet "chimney" (y-direction)

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Derived parameters

define(YCylUp, calc(sSDiameter/2.0)) //defining the 3 levels in y-direction
define(YCylDown, calc(-sSDiameter/2.0)) //as shown in the figure in the report
define(YOutlet, calc(sSDiameter/2 + outletHeight))
define(ZPiston, calc(-lengthOfMovSleeve - lengthOfFixSleeve)) //defining the 3 levels in z-direction
define(ZboundaryMovingFix, -lengthOfFixSleeve) //as shown in the figure in the report
define(ZEndOfSleeve, 0)
define(Xf, calc(thickness/2.0)) // Xf for x-coordinate of the front
define(Xb, calc(Xf - thickness)) // // Xb for x-coordinate of the back

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Parametric description

vertices
(
(Xb YCylDown ZPiston) vlabel(bpd)
(Xb YCylUp ZPiston) vlabel(bpu)
(Xb YCylDown ZboundaryMovingFix) vlabel(bibll)
(Xb YCylUp ZboundaryMovingFix) vlabel(bibul)
(Xb YOutlet ZboundaryMovingFix) vlabel(bol)
(Xb YCylDown ZEndOfSleeve) vlabel(blr)
(Xb YCylUp ZEndOfSleeve) vlabel(bibur)
(Xb YOutlet ZEndOfSleeve) vlabel(bor)
(Xf YCylDown ZPiston) vlabel(fpd)
(Xf YCylUp ZPiston) vlabel(fpu)
(Xf YCylDown ZboundaryMovingFix) vlabel(fibll)
(Xf YCylUp ZboundaryMovingFix) vlabel(fibul)
(Xf YOutlet ZboundaryMovingFix) vlabel(fol)
(Xf YCylDown ZEndOfSleeve) vlabel(flr)
(Xf YCylUp ZEndOfSleeve) vlabel(fibur)
(Xf YOutlet ZEndOfSleeve) vlabel(for)
);

blocks
(
// block0
hex2D(pd, pu, ibul, ibll)
(NHoSS NmA Nt)
simpleGrading (1 1 1)
// block1
hex2D(ibll, ibul, ibur, lr)
(NHoSS NfA Nt)
simpleGrading (1 1 1)
// block2
hex2D(ibul, ol, or, ibur)
(NOH NfA Nt)
simpleGrading (1 1 1)
);

boundary
(
slipWalls
{
type wall;
faces
(
quad2D(pd, ibll)
quad2D(ibul, pu)
);
}
movingWalls
{
type wall;
faces
(
quad2D(pu, pd)
);
}
fixedWalls
{
type wall;
faces
(
quad2D(ibur, or)
quad2D(ol, ibul)
quad2D(ibll, lr)
quad2D(lr, ibur)
);
}
outlet
{
type patch;
faces
(
quad2D(or, ol)
);
}
frontAndBack
{
type empty;
faces
(
frontQuad(pd, ibll, ibul, pu)
frontQuad(ibll, lr, ibur, ibul)
frontQuad(ibul, ibur, or, ol)
backQuad(pd, ibll, ibul, pu)
backQuad(ibll, lr, ibur, ibul)
backQuad(ibul, ibur, or, ol)
);
}
);
// ************************************************************************* //
